@@ -1,5 +1,4 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-pub mod components;
-pub mod macros;
+pub mod widgets;
 pub mod window;
